@@ -34,7 +34,7 @@ function action_desinstaller_plugin_dist() {
 
 	$securiser_action = charger_fonction('securiser_action', 'inc');
 	$arg = $securiser_action();
-	list($dir_plugins, $plugin) = explode('::', $arg);
+	[$dir_plugins, $plugin] = explode('::', $arg);
 	$dir_type = '_DIR_PLUGINS';
 	if (defined('_DIR_PLUGINS_SUPPL') and $dir_plugins == _DIR_PLUGINS_SUPPL) {
 		$dir_type = '_DIR_PLUGINS_SUPPL';
