@@ -47,14 +47,14 @@ function dump_afficher_tables_sauvegardees($status_file) {
 	}
 
 	$corps = '';
-	switch (count($tables)) {
+	switch (is_countable($tables) ? count($tables) : 0) {
 		case 0:
 			break;
 		case 1:
 			$corps = "<div style='width:49%;float:left;'><ul class='spip'><li class='spip'>" . join("</li><li class='spip'>", $tables) . '</li></ul></div>';
 			break;
 		default:
-			$n = floor(count($tables) / 2);
+			$n = floor((is_countable($tables) ? count($tables) : 0) / 2);
 			$corps = "<div style='width:49%;float:left;'><ul class='spip'><li class='spip'>" .
 				join("</li><li class='spip'>", array_slice($tables, 0, $n)) . '</li></ul></div>'
 				. "<div style='width:49%;float:left;'><ul class='spip'><li>" . join(
