@@ -19,14 +19,12 @@ include_spip('inc/actions');
 
 // Ce fichier est inclus par dist/formulaires/forum.php
 
-// https://code.spip.net/@mots_du_forum
 function mots_du_forum($ajouter_mot, $id_message) {
 	include_spip('action/editer_mot');
 	mot_associer($ajouter_mot, ['forum' => $id_message]);
 }
 
 
-// https://code.spip.net/@tracer_erreur_forum
 function tracer_erreur_forum($type = '') {
 	spip_log("erreur forum ($type): " . print_r($_POST, true));
 
@@ -46,8 +44,6 @@ function tracer_erreur_forum($type = '') {
 /**
  * Un parametre permet de forcer le statut (exemple: plugin antispam)
  *
- * https://code.spip.net/@inc_forum_insert_dist
- *
  * @param $objet
  * @param $id_objet
  * @param $id_forum
@@ -102,9 +98,9 @@ function inc_forum_insert_dist($objet, $id_objet, $id_forum, $force_statut = nul
 	return $id_reponse;
 }
 
-// https://code.spip.net/@forum_insert_base
 function forum_insert_base($c, $id_forum, $objet, $id_objet, $statut, $ajouter_mot = false) {
 
+	$files = [];
 	if (!in_array($statut, ['privrac', 'privadm'])) {
 		// si le statut est vide, c'est qu'on ne veut pas de ce presume spam !
 		if (!$statut or !$objet or !$id_objet) {
@@ -127,7 +123,6 @@ function forum_insert_base($c, $id_forum, $objet, $id_objet, $statut, $ajouter_m
 	$id_reponse = forum_inserer($id_forum, $set);
 
 	if ($id_reponse) {
-
 		// Entrer les mots-cles associes
 		if ($ajouter_mot) {
 			mots_du_forum($ajouter_mot, $id_reponse);
@@ -175,7 +170,6 @@ function forum_insert_base($c, $id_forum, $objet, $id_objet, $statut, $ajouter_m
 }
 
 
-// https://code.spip.net/@forum_insert_statut
 function forum_insert_statut($champs, $forcer_statut = null) {
 	include_spip('inc/forum');
 	$statut = controler_forum($champs['objet'], $champs['id_objet']);
