@@ -17,7 +17,6 @@ if (!defined('_ECRIRE_INC_VERSION')) {
 //
 // <BOUCLE(FORUMS)>
 //
-// https://code.spip.net/@boucle_FORUMS_dist
 function boucle_FORUMS_dist($id_boucle, &$boucles) {
 	$boucle = &$boucles[$id_boucle];
 	$id_table = $boucle->id_table;
@@ -39,14 +38,11 @@ function boucle_FORUMS_dist($id_boucle, &$boucles) {
 
 // {meme_parent}
 // https://www.spip.net/@meme_parent
-// https://code.spip.net/@critere_meme_parent_dist
 function critere_FORUMS_meme_parent_dist($idb, &$boucles, $crit) {
 	global $exceptions_des_tables;
 	$boucle = &$boucles[$idb];
 	$arg = kwote(calculer_argument_precedent($idb, 'id_parent', $boucles));
-	$id_parent = isset($exceptions_des_tables[$boucle->id_table]['id_parent']) ?
-		$exceptions_des_tables[$boucle->id_table]['id_parent'] :
-		'id_parent';
+	$id_parent = $exceptions_des_tables[$boucle->id_table]['id_parent'] ?? 'id_parent';
 	$mparent = $boucle->id_table . '.' . $id_parent;
 
 	$boucle->where[] = ["'='", "'$mparent'", $arg];
@@ -85,9 +81,7 @@ function critere_FORUMS_meme_parent_dist($idb, &$boucles, $crit) {
 function critere_FORUMS_compter_reponses($idb, &$boucles, $crit) {
 	$boucle = &$boucles[$idb];
 
-	$id_parent = isset($GLOBALS['exceptions_des_tables'][$boucle->id_table]['id_parent']) ?
-		$GLOBALS['exceptions_des_tables'][$boucle->id_table]['id_parent'] :
-		'id_parent';
+	$id_parent = $GLOBALS['exceptions_des_tables'][$boucle->id_table]['id_parent'] ?? 'id_parent';
 
 	$id_table = $boucle->id_table;
 
@@ -98,7 +92,7 @@ function critere_FORUMS_compter_reponses($idb, &$boucles, $crit) {
 	$boucle->select[] = 'COUNT(fils.id_forum) AS nombre_reponses';
 
 	// Gestion du having
-	if (count($crit->param)) {
+	if (is_countable($crit->param) ? count($crit->param) : 0) {
 		$champ = $crit->param[0][0]->texte;
 		if (preg_match(',^(\w+)\s*([<>=])\s*([0-9]+)$,', $champ, $r)) {
 			$champ = $r[1];
@@ -159,7 +153,6 @@ function public_critere_secteur_forums_dist($idb, &$boucles, $val, $crit) {
 // par exemple en tete de inc-forums.html ; impossible donc de
 // savoir a quel objet elle va s'appliquer, ca dependra du contexte
 //
-// https://code.spip.net/@balise_PARAMETRES_FORUM_dist
 function balise_PARAMETRES_FORUM_dist($p) {
 
 	// s'il y a un id_article dans le contexte, regarder le statut
@@ -307,7 +300,6 @@ function quete_accepter_forum($id_article) {
 // pour une boucle forum sans id_article ou id_rubrique donne par le contexte
 // et c'est signale par un message d'erreur abscons: "table inconnue forum".
 //
-// https://code.spip.net/@lang_parametres_forum
 function lang_parametres_forum($qs, $lang) {
 	if (is_array($lang) and preg_match(',id_([a-z_]+)=([0-9]+),', $qs, $r)) {
 		$id = 'id_' . $r[1];
@@ -327,7 +319,6 @@ function lang_parametres_forum($qs, $lang) {
 // Pour que le compilo ajoute un invalideur a la balise #PARAMETRES_FORUM
 // Noter l'invalideur de la page contenant ces parametres,
 // en cas de premier post sur le forum
-// https://code.spip.net/@code_invalideur_forums
 function code_invalideur_forums_dist($p, $code) {
 	return $code;
 }
