@@ -247,14 +247,10 @@ function auth_init_droits($row) {
 	$GLOBALS['connect_login'] = $row['login'];
 	$GLOBALS['connect_statut'] = $row['statut'];
 
-	$GLOBALS['visiteur_session'] = array_merge((array)$GLOBALS['visiteur_session'], $row);
+	$GLOBALS['visiteur_session'] = array_merge((array) $GLOBALS['visiteur_session'], $row);
 
 	// au cas ou : ne pas memoriser les champs sensibles
-	unset($GLOBALS['visiteur_session']['pass']);
-	unset($GLOBALS['visiteur_session']['htpass']);
-	unset($GLOBALS['visiteur_session']['alea_actuel']);
-	unset($GLOBALS['visiteur_session']['alea_futur']);
-	unset($GLOBALS['visiteur_session']['ldap_password']);
+	$GLOBALS['visiteur_session'] = auth_desensibiliser_session($GLOBALS['visiteur_session']);
 
 	// creer la session au besoin
 	if (!isset($_COOKIE['spip_session'])) {
@@ -314,6 +310,20 @@ function auth_init_droits($row) {
 	return ''; // i.e. pas de pb.
 }
 
+/**
+ * Enlever les clés sensibles d'une ligne auteur
+ */
+function auth_desensibiliser_session(array $auteur): array {
+	$cles_sensibles = ['pass', 'htpass', 'low_sec', 'alea_actuel', 'alea_futur', 'ldap_password', 'backup_cles'];
+	foreach ($cles_sensibles as $cle) {
+		if (array_key_exists($cle, $auteur)) {
+			unset($auteur[$cle]);
+		}
+	}
+
+	return $auteur;
+}
+
 /**
  * Retourne l'url de connexion
  *
@@ -480,6 +490,7 @@ function auth_informer_login($login, $serveur = '') {
 	}
 
 	$prefs = @unserialize($row['prefs']);
+	$row = auth_desensibiliser_session($row);
 	$infos = [
 		'id_auteur' => $row['id_auteur'],
 		'login' => $row['login'],
