@@ -107,9 +107,6 @@ function definir_barre_boutons($contexte = [], $icones = true, $autorise = true)
 				and $parent = preg_replace(',^bando_,', 'menu_', $parent)
 				and isset($boutons_admin[$parent])
 			) {
-				if (!is_array($boutons_admin[$parent]->sousmenu)) {
-					$boutons_admin[$parent]->sousmenu = [];
-				}
 				$position = (isset($infos['position']) and strlen($infos['position'])) ? intval($infos['position']) : count($boutons_admin[$parent]->sousmenu);
 				if ($position < 0) {
 					$position = count($boutons_admin[$parent]->sousmenu) + 1 + $position;
@@ -226,7 +223,7 @@ function bandeau_creer_url($url, $args = '', $contexte = null) {
 				$contexte['id_secteur'] = sql_getfetsel('id_secteur', 'spip_rubriques', 'id_rubrique=' . intval($contexte['id_rubrique']));
 			}
 			$val = _request($matches[2], $contexte);
-			$url = parametre_url($url, $matches[1], $val ? $val : '', '&');
+			$url = parametre_url($url, $matches[1], $val ?: '', '&');
 		}
 		$url = str_replace('&', '&amp;', $url);
 	}
