@@ -192,7 +192,7 @@ var mediaboxInit = function() {
 
 	// box auto sur tous les liens vers des images
 	if (b.tt_img) {
-		$('a[type^="image"],a[href$=".png"],a[href$=".jpg"],a[href$=".jpeg"],a[href$=".svg"]')
+		$('a[type^="image"],a[href$=".png"],a[href$=".jpg"],a[href$=".jpeg"],a[href$=".svg"],a[href$=".webp"]')
 		.not('.hasbox')
 		.removeAttr('onclick') // se debarrasser du onclick de SPIP
 		.mediabox({type:'image'})
