@@ -116,7 +116,7 @@
 
 			var t =
 				  '<dialog class="box_mediabox box_modalbox lity' + className + '" role="dialog" aria-label="' + dialog_title + '" tabindex="-1">'
-				+   '<div class="lity-wrap" data-lity-close role="document">'
+				+   '<div class="lity-wrap"' + (cfg.overlayClose === false ? '' : ' data-lity-close') + ' role="document">'
 				+     '<div class="lity-loader" aria-hidden="true" aria-label="' + litySpip.strings.loading + '"><span class="box-loading"></span></div>'
 				+     '<div class="lity-container"' + styles_container + '>'
 				+       '<button class="lity-close" type="button" aria-label="' + close_button_aria_label + '" data-lity-close><b data-lity-close title="' + litySpip.strings.close +'">&times;</b></button>'
@@ -131,8 +131,6 @@
 			return '<div class="error lity-error">Failed loading content</div>';
 		},
 		ajaxHandler: function (target, instance){
-			var cacheStore = (instance.opener().length ? instance.opener() : $(document));
-			var cache = cacheStore.data('lity-ajax-cache') || {};
 			// prise en charge de la syntaxe "url selector" comme jQuery.load()
 			var selector,
 				off = target.indexOf(" ");
@@ -143,9 +141,9 @@
 				target = target.slice(0, off);
 			}
 
-			if (cache[target]){
+			if (jQuery.spip.preloaded_urls[target]){
 				//console.log("CACHE for "+target);
-				var content = cache[target];
+				var content = jQuery.spip.preloaded_urls[target];
 				if (selector){
 					// If a selector was specified, locate the right elements in a dummy div
 					// Exclude scripts to avoid IE 'Permission Denied' errors
@@ -161,8 +159,7 @@
 			};
 			$.get(target)
 				.done(function (content){
-					cache[target] = content;
-					cacheStore.data('lity-ajax-cache', cache);
+					jQuery.spip.preloaded_urls[target] = content;
 					if (selector){
 						// If a selector was specified, locate the right elements in a dummy div
 						// Exclude scripts to avoid IE 'Permission Denied' errors
@@ -612,4 +609,4 @@
 	// on écrase la config juste une fois
 	initConfig();
 
-})(jQuery);
\ No newline at end of file
+})(jQuery);
