@@ -614,7 +614,11 @@ function _mysql_traite_query($query, $db = '', $prefixe = '', $echappe_textes =
  **/
 function spip_mysql_selectdb($db, $serveur = '', $requeter = true) {
 	$link = _mysql_link($serveur);
-	$ok = mysqli_select_db($link, $db);
+	try {
+		$ok = mysqli_select_db($link, $db);
+	} catch (\mysqli_sql_exception $e) {
+		$ok = false;
+	}
 	if (!$ok) {
 		spip_log('Echec mysqli_selectdb. Erreur : ' . mysqli_error($link), 'mysql.' . _LOG_CRITIQUE);
 	}
@@ -1033,7 +1037,10 @@ function spip_mysql_showtable($nom_table, $serveur = '', $requeter = true) {
  * @param string $t Structure de résultat attendu (défaut MYSQLI_ASSOC)
  * @param string $serveur Nom de la connexion
  * @param bool $requeter Inutilisé
- * @return array           Ligne de résultat
+ * @return array|null|false
+ *     - array Ligne de résultat
+ *     - null Pas de résultat
+ *     - false Erreur
  */
 function spip_mysql_fetch($r, $t = '', $serveur = '', $requeter = true) {
 	if (!$t) {
@@ -1042,6 +1049,7 @@ function spip_mysql_fetch($r, $t = '', $serveur = '', $requeter = true) {
 	if ($r) {
 		return mysqli_fetch_array($r, $t);
 	}
+	return false;
 }
 
 /**
