@@ -94,17 +94,21 @@ function inc_stats_visites_to_array_dist($unite, ?int $duree = null, ?string $ob
 		$startDate = (new \DateTime())->sub(new \DateInterval('P' . ($period_duration - 1) . $period_unit_interval))->format($format);
 	}
 
-	if ($objet and $id_objet) {
+	if ($objet) {
 		if ($objet === 'article') {
 			$table = 'spip_visites_articles';
-			$where[] = 'id_article=' . intval($id_objet);
+			if ($id_objet) {
+				$where[] = 'id_article=' . intval($id_objet);
+			}
 		} else {
 			// plugin stats objets ?
 			$trouver_table = charger_fonction('trouver_table', 'base');
 			if ($trouver_table('spip_visites_objets')) {
 				$table = 'spip_visites_objets';
-				$where[] = 'objet=' . table_objet($objet);
-				$where[] = 'id_objet=' . intval($id_objet);
+				$where[] = 'objet=' . sql_quote(objet_type($objet));
+				if ($id_objet) {
+					$where[] = 'id_objet=' . intval($id_objet);
+				}
 			} else {
 				throw new \Exception('Table spip_visites_objets not found. You need a plugin for stats outside articles.');
 			}
@@ -162,4 +166,4 @@ function inc_stats_visites_to_array_dist($unite, ?int $duree = null, ?string $ob
 	];
 
 	return array_values($data);
-}
+}
\ No newline at end of file
